I18nFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • I18nFlutterPlatform
Implementers

Constructors

I18nFlutterPlatform()
Constructs a I18nFlutterPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance I18nFlutterPlatform
The default instance of I18nFlutterPlatform to use.
getter/setter pair